summaryrefslogtreecommitdiffstats
path: root/src/server/events/Connect.cpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2012-05-11 03:56:54 +0000
committerDavid Robillard <d@drobilla.net>2012-05-11 03:56:54 +0000
commit3dd4b42f3054f819c865e9415c4b86ba78d43aec (patch)
tree656d152cdffdd9196013fe9f35d46f4cf73c6927 /src/server/events/Connect.cpp
parent7be6d5d05756a7dea20c494d56f364b4dc064c88 (diff)
downloadingen-3dd4b42f3054f819c865e9415c4b86ba78d43aec.tar.gz
ingen-3dd4b42f3054f819c865e9415c4b86ba78d43aec.tar.bz2
ingen-3dd4b42f3054f819c865e9415c4b86ba78d43aec.zip
"Connection" => "Edge"
git-svn-id: http://svn.drobilla.net/lad/trunk/ingen@4345 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'src/server/events/Connect.cpp')
-rw-r--r--src/server/events/Connect.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/server/events/Connect.cpp b/src/server/events/Connect.cpp
index 1fe88c22..7f28c3e6 100644
--- a/src/server/events/Connect.cpp
+++ b/src/server/events/Connect.cpp
@@ -24,7 +24,7 @@
#include "ClientBroadcaster.hpp"
#include "Connect.hpp"
-#include "ConnectionImpl.hpp"
+#include "EdgeImpl.hpp"
#include "DuplexPort.hpp"
#include "Engine.hpp"
#include "EngineStore.hpp"
@@ -92,13 +92,13 @@ Connect::pre_process()
return;
}
- if (!ConnectionImpl::can_connect(_src_output_port, _dst_input_port)) {
+ if (!EdgeImpl::can_connect(_src_output_port, _dst_input_port)) {
_status = TYPE_MISMATCH;
Event::pre_process();
return;
}
// Connection to a patch port from inside the patch
if (src_node->parent_patch() != dst_node->parent_patch()) {
assert(src_node->parent() == dst_node || dst_node->parent() == src_node);
if (src_node->parent() == dst_node)
@@ -106,30 +106,30 @@ Connect::pre_process()
else
_patch = dynamic_cast<PatchImpl*>(src_node);
// Connection from a patch input to a patch output (pass through)
} else if (src_node == dst_node && dynamic_cast<PatchImpl*>(src_node)) {
_patch = dynamic_cast<PatchImpl*>(src_node);
// Normal connection between nodes with the same parent
} else {
_patch = src_node->parent_patch();
}
- if (_patch->has_connection(_src_output_port, _dst_input_port)) {
+ if (_patch->has_edge(_src_output_port, _dst_input_port)) {
_status = EXISTS;
Event::pre_process();
return;
}
- _connection = SharedPtr<ConnectionImpl>(
- new ConnectionImpl(_src_output_port, _dst_input_port));
+ _edge = SharedPtr<EdgeImpl>(
+ new EdgeImpl(_src_output_port, _dst_input_port));
rlock.release();
{
Glib::RWLock::ReaderLock wlock(_engine.engine_store()->lock());
/* Need to be careful about patch port connections here and adding a
node's parent as a dependant/provider, or adding a patch as its own
provider...
*/
@@ -138,8 +138,8 @@ Connect::pre_process()
src_node->dependants().push_back(dst_node);
}
- _patch->add_connection(_connection);
- _dst_input_port->increment_num_connections();
+ _patch->add_edge(_edge);
+ _dst_input_port->increment_num_edges();
}
_buffers = new Raul::Array<BufferRef>(_dst_input_port->poly());
@@ -159,7 +159,7 @@ Connect::execute(ProcessContext& context)
if (_status == SUCCESS) {
// This must be inserted here, since they're actually used by the audio thread
- _dst_input_port->add_connection(_connection.get());
+ _dst_input_port->add_edge(_edge.get());
assert(_buffers);
_engine.maid()->push(_dst_input_port->set_buffers(_buffers));
_dst_input_port->connect_buffers();
@@ -92,13 +92,13 @@ Connect::pre_process()
return;
}
- // Connection to a patch port from inside the patch
+ // Edge to a patch port from inside the patch
if (src_node->parent_patch() != dst_node->parent_patch()) {
assert(src_node->parent() == dst_node || dst_node->parent() == src_node);
@@ -106,30 +106,30 @@ Connect::pre_process()
else
_patch = dynamic_cast<PatchImpl*>(src_node);
- // Connection from a patch input to a patch output (pass through)
+ // Edge from a patch input to a patch output (pass through)
} else if (src_node == dst_node && dynamic_cast<PatchImpl*>(src_node)) {
_patch = dynamic_cast<PatchImpl*>(src_node);
@@ -106,30 +106,30 @@ Connect::pre_process()
} else if (src_node == dst_node && dynamic_cast<PatchImpl*>(src_node)) {
_patch = dynamic_cast<PatchImpl*>(src_node);
- // Normal connection between nodes with the same parent
+ // Normal edge between nodes with the same parent
} else {
_patch = src_node->parent_patch();
@@ -106,30 +106,30 @@ Connect::pre_process()
{
Glib::RWLock::ReaderLock wlock(_engine.engine_store()->lock());
- /* Need to be careful about patch port connections here and adding a
+ /* Need to be careful about patch port edges here and adding a
node's parent as a dependant/provider, or adding a patch as its own
provider...